@@ -17,7 +17,6 @@ import itertools
 import re
 
 import netaddr
-import six
 
 from oslo_utils import uuidutils
 
@@ -29,7 +28,6 @@ from django.forms import widgets
 from django.template.loader import get_template
 from django import urls
 from django.utils.encoding import force_text
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.functional import Promise
 from django.utils import html
 from django.utils.safestring import mark_safe
@@ -278,7 +276,7 @@ class SelectWidget(widgets.Widget):
 
     def get_data_attrs(self, option_label):
         other_html = []
-        if not isinstance(option_label, (six.string_types, Promise)):
+        if not isinstance(option_label, (str, Promise)):
             for data_attr in self.data_attrs:
                 data_value = html.conditional_escape(
                     force_text(getattr(option_label,
@@ -287,7 +285,7 @@ class SelectWidget(widgets.Widget):
         return ' '.join(other_html)
 
     def transform_option_label(self, option_label):
-        if (not isinstance(option_label, (six.string_types, Promise)) and
+        if (not isinstance(option_label, (str, Promise)) and
                 callable(self.transform)):
             option_label = self.transform(option_label)
         return html.conditional_escape(force_text(option_label))
@@ -436,7 +434,6 @@ class ThemableCheckboxInput(widgets.CheckboxInput):
 # NOTE(adriant): SubWidget was removed in Django 1.11 and thus has been moved
 # to our codebase until we redo how we handle widgets.
 @html.html_safe
-@python_2_unicode_compatible
 class SubWidget(object):
     """SubWidget class from django 1.10.7 codebase
 
@@ -459,7 +456,6 @@ class SubWidget(object):
 # Django 1.11 so ChoiceInput has been moved to our codebase until we redo how
 # we handle widgets.
 @html.html_safe
-@python_2_unicode_compatible
 class ChoiceInput(SubWidget):
     """ChoiceInput class from django 1.10.7 codebase
 
