@@ -169,19 +169,19 @@
         type = service.getResourceType('something');
       });
 
-      it('initActions calls initScope on item and batch actions', function () {
-        var action = {service: {initScope: angular.noop}};
-        spyOn(action.service, 'initScope');
+      it('initActions calls initAction on item and batch actions', function () {
+        var action = {service: {initAction: angular.noop}};
+        spyOn(action.service, 'initAction');
         type.batchActions.push(action);
         type.initActions({
           '$new': function () {
             return 4;
           }
         });
-        expect(action.service.initScope).toHaveBeenCalledWith(4);
+        expect(action.service.initAction).toHaveBeenCalled();
       });
 
-      it('initActions ignores initScope when not present', function () {
+      it('initActions ignores initAction when not present', function () {
         var action = {service: {}};
         type.batchActions.push(action);
         var returned = type.initActions({});
