@@ -138,8 +138,8 @@ class MultiTableMixin(object):
         param_name = filter_action.get_param_name()
         filter_string = request.POST.get(param_name)
         filter_string_session = request.session.get(param_name, "")
-        changed = (filter_string is not None
-                   and filter_string != filter_string_session)
+        changed = (filter_string is not None and
+                   filter_string != filter_string_session)
         if filter_string is None:
             filter_string = filter_string_session
         filter_field_param = param_name + '_field'
@@ -304,11 +304,13 @@ class DataTableView(MultiTableView):
                 filter_string = self.table.get_filter_string().strip()
                 if filter_field and filter_string:
                     filter_map = filters_map.get(filter_field, {})
-                    # We use the filter_string given by the user and
-                    # look for valid values in the filter_map that's why
-                    # we apply lower()
-                    filters[filter_field] = filter_map.get(
-                        filter_string.lower(), filter_string)
+                    filters[filter_field] = filter_string
+                    for k, v in filter_map.items():
+                        # k is django.utils.functional.__proxy__
+                        # and could not be searched in dict
+                        if filter_string.lower() == k:
+                            filters[filter_field] = v
+                            break
         return filters
 
 
