@@ -17,10 +17,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from importlib import import_module
-
-import six
-from six import moves
+import importlib
 
 from django.conf import settings
 from django.contrib.auth.models import User
@@ -45,19 +42,18 @@ class MyDash(horizon.Dashboard):
     default_panel = "myslug"
 
 
+class MyOtherDash(horizon.Dashboard):
+    name = "My Other Dashboard"
+    slug = "mydash2"
+    default_panel = "myslug2"
+
+
 class MyPanel(horizon.Panel):
     name = "My Panel"
     slug = "myslug"
     urls = 'horizon.test.test_dashboards.cats.kittens.urls'
 
 
-class AdminPanel(horizon.Panel):
-    name = "Admin Panel"
-    slug = "admin_panel"
-    permissions = ("horizon.test",)
-    urls = 'horizon.test.test_dashboards.cats.kittens.urls'
-
-
 class RbacNoAccessPanel(horizon.Panel):
     name = "RBAC Panel No"
     slug = "rbac_panel_no"
@@ -106,7 +102,7 @@ class BaseHorizonTests(test.TestCase):
         del base.Horizon
         base.Horizon = base.HorizonSite()
         # Reload the convenience references to Horizon stored in __init__
-        moves.reload_module(import_module("horizon"))
+        importlib.reload(importlib.import_module("horizon"))
         # Re-register our original dashboards and panels.
         # This is necessary because autodiscovery only works on the first
         # import, and calling reload introduces innumerable additional
@@ -126,7 +122,7 @@ class BaseHorizonTests(test.TestCase):
         Useful only for testing and should never be used on a live site.
         """
         urls.clear_url_caches()
-        moves.reload_module(import_module(settings.ROOT_URLCONF))
+        importlib.reload(importlib.import_module(settings.ROOT_URLCONF))
         base.Horizon._urls()
 
 
@@ -167,8 +163,34 @@ class HorizonTests(BaseHorizonTests):
         with self.assertRaises(base.NotRegistered):
             horizon.get_dashboard(MyDash)
 
+    def test_registry_two_dashboards(self):
+        "Verify registration of 2 dashboards"
+
+        # Registration
+        self.assertEqual(2, len(base.Horizon._registry))
+        horizon.register(MyDash)
+        horizon.register(MyOtherDash)
+        self.assertEqual(4, len(base.Horizon._registry))
+
+        # Retrieval
+        self.assertQuerysetEqual(horizon.get_dashboards(),
+                                 ['<Dashboard: cats>',
+                                  '<Dashboard: dogs>',
+                                  '<Dashboard: mydash>',
+                                  '<Dashboard: mydash2>'])
+
+        # Removal
+        self.assertEqual(4, len(base.Horizon._registry))
+        horizon.unregister(MyDash)
+        horizon.unregister(MyOtherDash)
+        self.assertEqual(2, len(base.Horizon._registry))
+        with self.assertRaises(base.NotRegistered):
+            horizon.get_dashboard(MyDash)
+        with self.assertRaises(base.NotRegistered):
+            horizon.get_dashboard(MyOtherDash)
+
     def test_site(self):
-        self.assertEqual("Horizon", six.text_type(base.Horizon))
+        self.assertEqual("Horizon", str(base.Horizon))
         self.assertEqual("<Site: horizon>", repr(base.Horizon))
         dash = base.Horizon.get_dashboard('cats')
         self.assertEqual(dash, base.Horizon.get_default_dashboard())
@@ -190,7 +212,6 @@ class HorizonTests(BaseHorizonTests):
         cats.register(MyPanel)
         self.assertQuerysetEqual(cats.get_panel_groups()['other'],
                                  ['<Panel: myslug>'])
-
         # Test that panels defined as a tuple still return a PanelGroup
         dogs = horizon.get_dashboard("dogs")
         self.assertQuerysetEqual(dogs.get_panel_groups().values(),
@@ -203,6 +224,8 @@ class HorizonTests(BaseHorizonTests):
         self.assertQuerysetEqual(dogs.get_panels(),
                                  ['<Panel: puppies>',
                                   '<Panel: myslug>'])
+        cats.unregister(MyPanel)
+        dogs.unregister(MyPanel)
 
     def test_panels(self):
         cats = horizon.get_dashboard("cats")
@@ -499,7 +522,7 @@ class RbacHorizonTests(test.TestCase):
         del base.Horizon
         base.Horizon = base.HorizonSite()
         # Reload the convenience references to Horizon stored in __init__
-        moves.reload_module(import_module("horizon"))
+        importlib.reload(importlib.import_module("horizon"))
 
         # Reset Cats and Dogs default_panel to default values
         Cats.default_panel = 'kittens'
