@@ -15,13 +15,9 @@ from django.conf.urls import include
 from django.conf.urls import url
 from django.views import generic
 
-from openstack_auth import utils
 from openstack_auth import views
 
 
-utils.patch_middleware_get_user()
-
-
 urlpatterns = [
     url(r"", include('openstack_auth.urls')),
     url(r"^websso/$", views.websso, name='websso'),
