@@ -19,7 +19,9 @@
 from __future__ import absolute_import
 from __future__ import division
 
+import _thread as thread
 import collections
+from collections import abc
 import itertools
 import json
 import logging
@@ -32,8 +34,7 @@ from django.core.files.uploadedfile import TemporaryUploadedFile
 from django.utils.translation import ugettext_lazy as _
 
 from glanceclient.v2 import client
-import six
-from six.moves import _thread as thread
+
 
 from horizon import messages
 from horizon.utils.memoized import memoized
@@ -41,15 +42,6 @@ from openstack_dashboard.api import base
 from openstack_dashboard.contrib.developer.profiler import api as profiler
 from openstack_dashboard.utils import settings as utils
 
-# Python 3.8 removes the ability to import the abstract base classes from
-# 'collections', but 'collections.abc' is not present in Python 2.7
-# TODO(stephenfin): Remove when we drop support for Python 2.7
-# pylint: disable=ungrouped-imports
-if hasattr(collections, 'abc'):
-    from collections.abc import Iterable
-else:
-    from collections import Iterable
-
 
 LOG = logging.getLogger(__name__)
 VERSIONS = base.APIVersionManager("image", preferred_version=2)
@@ -119,7 +111,7 @@ class Image(base.APIResourceWrapper):
             return prop_name not in (self._attrs | self._ext_attrs)
 
     def to_dict(self, show_ext_attrs=False):
-        if not isinstance(self._apiresource, Iterable):
+        if not isinstance(self._apiresource, abc.Iterable):
             return self._apiresource.to_dict()
         image_dict = super(Image, self).to_dict()
         image_dict['is_public'] = self.is_public
@@ -252,7 +244,7 @@ def image_list_detailed(request, marker=None, sort_dir='desc',
 
     :param sort_key:
 
-        The name of key by by which the resulting image list throughout all
+        The name of key by which the resulting image list throughout all
         pages (if pagination is enabled) will be sorted. Defaults to
         'created_at'.
 
@@ -501,16 +493,13 @@ def image_create(request, **kwargs):
         glanceclient(request).images.add_location(image.id, location, {})
 
     if data:
-        if isinstance(data, six.string_types):
+        if isinstance(data, str):
             # The image data is meant to be uploaded externally, return a
             # special wrapper to bypass the web server in a subsequent upload
             return ExternallyUploadedImage(image, request)
         elif isinstance(data, TemporaryUploadedFile):
             # Hack to fool Django, so we can keep file open in the new thread.
-            if six.PY2:
-                data.file.close_called = True
-            else:
-                data.file._closer.close_called = True
+            data.file._closer.close_called = True
         elif isinstance(data, InMemoryUploadedFile):
             # Clone a new file for InMemeoryUploadedFile.
             # Because the old one will be closed by Django.
@@ -522,13 +511,17 @@ def image_create(request, **kwargs):
             try:
                 return glanceclient(request).images.upload(image.id, data)
             finally:
-                filename = str(data.file.name)
                 try:
-                    os.remove(filename)
-                except OSError as e:
-                    LOG.warning('Failed to remove temporary image file '
-                                '%(file)s (%(e)s)',
-                                {'file': filename, 'e': e})
+                    filename = str(data.file.name)
+                except AttributeError:
+                    pass
+                else:
+                    try:
+                        os.remove(filename)
+                    except OSError as e:
+                        LOG.warning('Failed to remove temporary image file '
+                                    '%(file)s (%(e)s)',
+                                    {'file': filename, 'e': e})
         thread.start_new_thread(upload, ())
 
     return Image(image)
