@@ -31,6 +31,7 @@ class AjaxError(Exception):
         self.http_status = http_status
         super(AjaxError, self).__init__(msg)
 
+
 http_errors = exceptions.UNAUTHORIZED + exceptions.NOT_FOUND + \
     exceptions.RECOVERABLE + (AjaxError, )
 
@@ -105,7 +106,7 @@ def ajax(authenticated=True, data_required=False,
         @functools.wraps(function,
                          assigned=decorators.available_attrs(function))
         def _wrapped(self, request, *args, **kw):
-            if authenticated and not request.user.is_authenticated():
+            if authenticated and not request.user.is_authenticated:
                 return JSONResponse('not logged in', 401)
             if not request.is_ajax():
                 return JSONResponse('request must be AJAX', 400)
@@ -147,6 +148,7 @@ def ajax(authenticated=True, data_required=False,
         return _wrapped
     return decorator
 
+
 PARAM_MAPPING = {
     'None': None,
     'True': True,
