@@ -17,10 +17,10 @@
 #    under the License.
 
 from datetime import datetime
+from urllib import parse
 
 import functools
 
-import six.moves.urllib.parse as urlparse
 import swiftclient
 
 from django.conf import settings
@@ -104,6 +104,13 @@ def _objectify(items, container_name):
     return objects
 
 
+def get_storage_policy_display_name(name):
+    """Gets the user friendly display name for a storage policy"""
+
+    display_names = settings.SWIFT_STORAGE_POLICY_DISPLAY_NAMES
+    return display_names.get(name)
+
+
 def _metadata_to_header(metadata):
     headers = {}
     public = metadata.get('is_public')
@@ -114,6 +121,10 @@ def _metadata_to_header(metadata):
     elif public is False:
         headers['x-container-read'] = ""
 
+    storage_policy = metadata.get("storage_policy")
+    if storage_policy:
+        headers["x-storage-policy"] = storage_policy
+
     return headers
 
 
@@ -166,7 +177,7 @@ def swift_get_containers(request, marker=None, prefix=None):
 
 @profiler.trace
 @safe_swift_exception
-def swift_get_container(request, container_name, with_data=True):
+def swift_get_container(request, container_name, with_data=False):
     if with_data:
         headers, data = swift_api(request).get_object(container_name, "")
     else:
@@ -175,13 +186,17 @@ def swift_get_container(request, container_name, with_data=True):
     timestamp = None
     is_public = False
     public_url = None
+    storage_policy = headers.get("x-storage-policy")
+    storage_policy_display_name = \
+        get_storage_policy_display_name(storage_policy)
+
     try:
         is_public = GLOBAL_READ_ACL in headers.get('x-container-read', '')
         if is_public:
             swift_endpoint = base.url_for(request,
                                           'object-store',
                                           endpoint_type='publicURL')
-            parameters = urlparse.quote(container_name.encode('utf8'))
+            parameters = parse.quote(container_name.encode('utf8'))
             public_url = swift_endpoint + '/' + parameters
         ts_float = float(headers.get('x-timestamp'))
         timestamp = datetime.utcfromtimestamp(ts_float).isoformat()
@@ -194,8 +209,16 @@ def swift_get_container(request, container_name, with_data=True):
         'timestamp': timestamp,
         'data': data,
         'is_public': is_public,
+        'storage_policy': {
+            "name": storage_policy,
+        },
         'public_url': public_url,
     }
+
+    if storage_policy_display_name:
+        container_info['storage_policy']['display_name'] = \
+            get_storage_policy_display_name(storage_policy)
+
     return Container(container_info)
 
 
