@@ -24,6 +24,12 @@ class Roles(horizon.Panel):
     slug = 'roles'
     policy_rules = (("identity", "identity:list_roles"),)
 
+    def can_access(self, context):
+        if keystone.is_multi_domain_enabled() \
+                and not keystone.is_domain_admin(context['request']):
+            return False
+        return super(Roles, self).can_access(context)
+
     @staticmethod
     def can_register():
         return keystone.VERSIONS.active >= 3
