@@ -21,7 +21,6 @@ from openstack_dashboard import policy
 
 ENABLE = 0
 DISABLE = 1
-KEYSTONE_V2_ENABLED = api.keystone.VERSIONS.active < 3
 
 
 class CreateUserLink(tables.LinkAction):
@@ -54,15 +53,20 @@ class EditUserLink(policy.PolicyTargetMixin, tables.LinkAction):
         return api.keystone.keystone_can_edit_user()
 
 
-class ChangePasswordLink(tables.LinkAction):
+class ChangePasswordLink(policy.PolicyTargetMixin, tables.LinkAction):
     name = "change_password"
     verbose_name = _("Change Password")
     url = "horizon:identity:users:change_password"
     classes = ("ajax-modal",)
     icon = "key"
+    policy_rules = (("identity", "identity:update_user"),)
+    policy_target_attrs = (("user_id", "id"),
+                           ("target.user.domain_id", "domain_id"))
 
     def allowed(self, request, user):
-        return api.keystone.keystone_can_edit_user()
+        options = getattr(user, "options", {})
+        lock_password = options.get("lock_password", False)
+        return not lock_password and api.keystone.keystone_can_edit_user()
 
 
 class ToggleEnabled(policy.PolicyTargetMixin, tables.BatchAction):
@@ -183,7 +187,6 @@ class UsersTable(tables.DataTable):
                                  form_field=forms.CharField(required=False))
     description = tables.Column(lambda obj: getattr(obj, 'description', None),
                                 verbose_name=_('Description'),
-                                hidden=KEYSTONE_V2_ENABLED,
                                 form_field=forms.CharField(
                                     widget=forms.Textarea(attrs={'rows': 4}),
                                     required=False))
