@@ -10,10 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack_dashboard.api import swift
+from django.core import validators
+from django.utils.translation import ugettext_lazy as _
 
 
-def wrap_delimiter(name):
-    if name and not name.endswith(swift.FOLDER_DELIMITER):
-        return name + swift.FOLDER_DELIMITER
-    return name
+no_slash_validator = validators.RegexValidator(r'^(?u)[^/]+$',
+                                               _("Slash is not an allowed "
+                                                 "character."),
+                                               code="noslash")
