@@ -23,19 +23,26 @@ from horizon.utils import memoized
 from horizon import workflows
 
 from openstack_dashboard import api
+from openstack_dashboard import policy
 from openstack_dashboard.utils import filters
 
-
 ALLOCATE_URL = "horizon:project:floating_ips:allocate"
 
 
 class AssociateIPAction(workflows.Action):
+    use_required_attribute = False
     ip_id = forms.ThemableDynamicTypedChoiceField(
         label=_("IP Address"),
         coerce=filters.get_int_or_uuid,
-        empty_value=None,
-        add_item_link=ALLOCATE_URL)
-    instance_id = forms.ThemableChoiceField(label=_("Port to be associated"))
+        empty_value=None
+    )
+    instance_id = forms.CharField(
+        widget=forms.widgets.HiddenInput(),
+        required=False,
+    )
+    port_id = forms.ThemableChoiceField(
+        label=_("Port to be associated")
+    )
 
     class Meta(object):
         name = _("IP Address")
@@ -50,23 +57,30 @@ class AssociateIPAction(workflows.Action):
         # an association target is not an instance but a port, so we need
         # to get an association target based on a received instance_id
         # and set the initial value of instance_id ChoiceField.
-        q_instance_id = self.request.GET.get('instance_id')
+        q_instance_id = self.data.get('instance_id',
+                                      self.request.GET.get('instance_id'))
         q_port_id = self.request.GET.get('port_id')
+
+        if policy.check((("network", "create_floatingip"),),
+                        request=self.request):
+            self.fields['ip_id'].widget.add_item_link = ALLOCATE_URL
+
         if q_instance_id:
+            self.initial['instance_id'] = q_instance_id
             targets = self._get_target_list(q_instance_id)
             # Setting the initial value here is required to avoid a situation
             # where instance_id passed in the URL is used as the initial value
             # unexpectedly. (This always happens if the form is invoked from
             # the instance table.)
             if targets:
-                self.initial['instance_id'] = targets[0].id
+                self.initial['port_id'] = targets[0].id
             else:
-                self.initial['instance_id'] = ''
+                self.initial['port_id'] = ''
         elif q_port_id:
             targets = self._get_target_list()
             for target in targets:
                 if target.port_id == q_port_id:
-                    self.initial['instance_id'] = target.id
+                    self.initial['port_id'] = target.id
                     break
 
     def populate_ip_id_choices(self, request, context):
@@ -104,9 +118,9 @@ class AssociateIPAction(workflows.Action):
                               redirect=redirect)
         return targets
 
-    # TODO(amotoki): [drop-nova-network] Rename instance_id to port_id
-    def populate_instance_id_choices(self, request, context):
-        q_instance_id = self.request.GET.get('instance_id')
+    def populate_port_id_choices(self, request, context):
+        q_instance_id = self.data.get('instance_id',
+                                      self.initial.get('instance_id'))
         # The reason of specifying an empty tuple when q_instance_id is None
         # is to make memoized_method _get_target_list work. Two calls of
         # _get_target_list from here and __init__ must have a same arguments.
@@ -124,7 +138,7 @@ class AssociateIPAction(workflows.Action):
 
 class AssociateIP(workflows.Step):
     action_class = AssociateIPAction
-    contributes = ("ip_id", "instance_id", "ip_address")
+    contributes = ("ip_id", "instance_id", "ip_address", "port_id")
 
     def contribute(self, data, context):
         context = super(AssociateIP, self).contribute(data, context)
@@ -155,7 +169,7 @@ class IPAssociationWorkflow(workflows.Workflow):
         try:
             api.neutron.floating_ip_associate(request,
                                               data['ip_id'],
-                                              data['instance_id'])
+                                              data['port_id'])
         except neutron_exc.Conflict:
             msg = _('The requested instance port is already'
                     ' associated with another floating IP.')
