@@ -17,14 +17,15 @@ import logging
 
 from django.conf import settings
 from django.http import HttpResponse
+from django import shortcuts
 from django import template
 from django.template.defaultfilters import title
 from django import urls
 from django.utils.http import urlencode
 from django.utils.safestring import mark_safe
+from django.utils.text import format_lazy
 from django.utils.translation import npgettext_lazy
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import string_concat
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 import netaddr
@@ -448,8 +449,10 @@ class LaunchLink(tables.LinkAction):
                     or ram_available <= 0:
                 if "disabled" not in self.classes:
                     self.classes = [c for c in self.classes] + ['disabled']
-                    self.verbose_name = string_concat(self.verbose_name, ' ',
-                                                      _("(Quota exceeded)"))
+                    self.verbose_name = format_lazy(
+                        '{verbose_name} {quota_exceeded}',
+                        verbose_name=self.verbose_name,
+                        quota_exceeded=_("(Quota exceeded)"))
             else:
                 self.verbose_name = _("Launch Instance")
                 classes = [c for c in self.classes if c != "disabled"]
@@ -557,8 +560,9 @@ class ConsoleLink(policy.PolicyTargetMixin, tables.LinkAction):
     def allowed(self, request, instance=None):
         # We check if ConsoleLink is allowed only if settings.CONSOLE_TYPE is
         # not set at all, or if it's set to any value other than None or False.
-        return bool(getattr(settings, 'CONSOLE_TYPE', True)) and \
-            instance.status in ACTIVE_STATES and not is_deleting(instance)
+        return (bool(settings.CONSOLE_TYPE) and
+                instance.status in ACTIVE_STATES and
+                not is_deleting(instance))
 
     def get_link_url(self, datum):
         base_url = super(ConsoleLink, self).get_link_url(datum)
@@ -620,6 +624,7 @@ class ConfirmResize(policy.PolicyTargetMixin, tables.Action):
 
     def single(self, table, request, instance):
         api.nova.server_confirm_resize(request, instance)
+        return shortcuts.redirect(request.get_full_path())
 
 
 class RevertResize(policy.PolicyTargetMixin, tables.Action):
@@ -660,10 +665,7 @@ class DecryptInstancePassword(tables.LinkAction):
     url = "horizon:project:instances:decryptpassword"
 
     def allowed(self, request, instance):
-        enable = getattr(settings,
-                         'OPENSTACK_ENABLE_PASSWORD_RETRIEVE',
-                         False)
-        return (enable and
+        return (settings.OPENSTACK_ENABLE_PASSWORD_RETRIEVE and
                 (instance.status in ACTIVE_STATES or
                  instance.status == 'SHUTOFF') and
                 not is_deleting(instance) and
@@ -772,7 +774,8 @@ def get_instance_error(instance):
     message = instance_fault_to_friendly_message(instance)
     preamble = _('Failed to perform requested operation on instance "%s", the '
                  'instance has an error status') % instance.name or instance.id
-    message = string_concat(preamble, ': ', message)
+    message = format_lazy('{preamble}: {message}',
+                          preamble=preamble, message=message)
     return message
 
 
@@ -1293,9 +1296,9 @@ class InstancesTable(tables.DataTable):
         row_class = UpdateRow
         table_actions_menu = (StartInstance, StopInstance, SoftRebootInstance)
         launch_actions = ()
-        if getattr(settings, 'LAUNCH_INSTANCE_LEGACY_ENABLED', False):
+        if settings.LAUNCH_INSTANCE_LEGACY_ENABLED:
             launch_actions = (LaunchLink,) + launch_actions
-        if getattr(settings, 'LAUNCH_INSTANCE_NG_ENABLED', True):
+        if settings.LAUNCH_INSTANCE_NG_ENABLED:
             launch_actions = (LaunchLinkNG,) + launch_actions
         table_actions = launch_actions + (DeleteInstance,
                                           InstancesFilterAction)
