@@ -21,7 +21,6 @@ import logging
 import operator
 
 from oslo_utils import units
-import six
 
 from django.template.defaultfilters import filesizeformat
 from django.utils.text import normalize_newlines
@@ -41,6 +40,8 @@ from openstack_dashboard.api import cinder
 from openstack_dashboard.api import nova
 from openstack_dashboard.usage import quotas
 
+from openstack_dashboard.dashboards.project.images.images \
+    import tables as image_tables
 from openstack_dashboard.dashboards.project.images \
     import utils as image_utils
 from openstack_dashboard.dashboards.project.instances \
@@ -392,7 +393,9 @@ class SetInstanceDetailsAction(workflows.Action):
     def get_help_text(self, extra_context=None):
         extra = {} if extra_context is None else dict(extra_context)
         try:
-            extra['usages'] = quotas.tenant_limit_usages(self.request)
+            extra['usages'] = quotas.tenant_quota_usages(
+                self.request,
+                targets=('instances', 'cores', 'ram', 'volumes', 'gigabytes'))
             extra['usages_json'] = json.dumps(extra['usages'])
             extra['cinder_enabled'] = \
                 base.is_service_enabled(self.request, 'volume')
@@ -437,7 +440,7 @@ class SetInstanceDetailsAction(workflows.Action):
                                                   context.get('project_id'),
                                                   self._images_cache)
         for image in images:
-            if image.properties.get("image_type", '') != "snapshot":
+            if image_tables.get_image_type(image) != "snapshot":
                 image.bytes = getattr(
                     image, 'virtual_size', None) or image.size
                 image.volume_size = max(
@@ -459,7 +462,7 @@ class SetInstanceDetailsAction(workflows.Action):
                                                   self._images_cache)
         choices = [(image.id, image.name)
                    for image in images
-                   if image.properties.get("image_type", '') == "snapshot"]
+                   if image_tables.get_image_type(image) == "snapshot"]
         if choices:
             choices.sort(key=operator.itemgetter(1))
             choices.insert(0, ("", _("Select Instance Snapshot")))
@@ -489,9 +492,12 @@ class SetInstanceDetailsAction(workflows.Action):
         try:
             if cinder.is_volume_service_enabled(request):
                 available = api.cinder.VOLUME_STATE_AVAILABLE
+                volumes = [v.id for v in cinder.volume_list(
+                           self.request, search_opts=dict(bootable=True))]
                 snapshots = [self._get_volume_display_name(s)
                              for s in cinder.volume_snapshot_list(
-                             self.request, search_opts=dict(status=available))]
+                             self.request, search_opts=dict(status=available))
+                             if s.volume_id in volumes]
         except Exception:
             exceptions.handle(self.request,
                               _('Unable to retrieve list of volume '
@@ -519,8 +525,9 @@ class SetInstanceDetails(workflows.Step):
     def contribute(self, data, context):
         context = super(SetInstanceDetails, self).contribute(data, context)
         # Allow setting the source dynamically.
-        if ("source_type" in context and "source_id" in context
-                and context["source_type"] not in context):
+        if ("source_type" in context and
+                "source_id" in context and
+                context["source_type"] not in context):
             context[context["source_type"]] = context["source_id"]
 
         # Translate form input to context for source values.
@@ -655,9 +662,6 @@ class CustomizeAction(workflows.Action):
             'data-scriptsource-raw': _('Script Data')}),
         required=False)
 
-    def __init__(self, *args):
-        super(CustomizeAction, self).__init__(*args)
-
     def clean(self):
         cleaned = super(CustomizeAction, self).clean()
 
@@ -685,12 +689,14 @@ class CustomizeAction(workflows.Action):
                 script = upload_file.read()
                 if script != "":
                     try:
+                        if not isinstance(script, str):
+                            script = script.decode()
                         normalize_newlines(script)
                     except Exception as e:
                         msg = _('There was a problem parsing the'
                                 ' %(prefix)s: %(error)s')
                         msg = msg % {'prefix': prefix,
-                                     'error': six.text_type(e)}
+                                     'error': e}
                         raise forms.ValidationError(msg)
                 return script
         else:
@@ -732,7 +738,7 @@ class SetNetworkAction(workflows.Action):
         help_text = _("Select networks for your instance.")
 
     def populate_network_choices(self, request, context):
-        return instance_utils.network_field_data(request)
+        return instance_utils.network_field_data(request, for_launch=True)
 
 
 class SetNetwork(workflows.Step):
