@@ -28,6 +28,7 @@ from horizon import workflows
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.networks.subnets import utils
 from openstack_dashboard import policy
+from openstack_dashboard.utils import settings as setting_utils
 
 
 LOG = logging.getLogger(__name__)
@@ -41,7 +42,7 @@ class CreateNetworkInfoAction(workflows.Action):
         label=_("Enable Admin State"),
         initial=True,
         required=False,
-        help_text=_("The state to start the network in."))
+        help_text=_("If checked, the network will be enabled."))
     shared = forms.BooleanField(label=_("Shared"), initial=False,
                                 required=False)
     with_subnet = forms.BooleanField(label=_("Create Subnet"),
@@ -139,6 +140,7 @@ class CreateSubnetInfoAction(workflows.Action):
                                   required=False)
 
     cidr = forms.IPField(label=_("Network Address"),
+                         required=False,
                          initial="",
                          error_messages={
                              'required': _('Specify "Network Address" or '
@@ -204,8 +206,8 @@ class CreateSubnetInfoAction(workflows.Action):
     def __init__(self, request, context, *args, **kwargs):
         super(CreateSubnetInfoAction, self).__init__(request, context, *args,
                                                      **kwargs)
-        if not getattr(settings, 'OPENSTACK_NEUTRON_NETWORK',
-                       {}).get('enable_ipv6', True):
+        if not setting_utils.get_dict_config('OPENSTACK_NEUTRON_NETWORK',
+                                             'enable_ipv6'):
             self.fields['ip_version'].widget = forms.HiddenInput()
             self.fields['ip_version'].initial = 4
 
@@ -260,7 +262,7 @@ class CreateSubnetInfoAction(workflows.Action):
         if not self.check_subnet_range:
             return
 
-        allowed_cidr = getattr(settings, "ALLOWED_PRIVATE_SUBNET_CIDR", {})
+        allowed_cidr = settings.ALLOWED_PRIVATE_SUBNET_CIDR
         version_str = 'ipv%s' % ip_version
         allowed_ranges = allowed_cidr.get(version_str, [])
         if allowed_ranges:
@@ -287,6 +289,10 @@ class CreateSubnetInfoAction(workflows.Action):
                     '"Enter Network Address manually" and specify '
                     '"Network Address".')
             raise forms.ValidationError(msg)
+        if not cidr and address_source != 'subnetpool':
+            msg = _('Specify "Network Address" or '
+                    'clear "Create Subnet" checkbox in previous step.')
+            raise forms.ValidationError(msg)
         if address_source == 'subnetpool' and 'cidr' in self._errors:
             del self._errors['cidr']
         elif cidr:
@@ -376,8 +382,8 @@ class CreateSubnetDetailAction(workflows.Action):
     def __init__(self, request, context, *args, **kwargs):
         super(CreateSubnetDetailAction, self).__init__(request, context,
                                                        *args, **kwargs)
-        if not getattr(settings, 'OPENSTACK_NEUTRON_NETWORK',
-                       {}).get('enable_ipv6', True):
+        if not setting_utils.get_dict_config('OPENSTACK_NEUTRON_NETWORK',
+                                             'enable_ipv6'):
             self.fields['ipv6_modes'].widget = forms.HiddenInput()
 
     def populate_ipv6_modes_choices(self, request, context):
