@@ -34,9 +34,11 @@ LOG = logging.getLogger(__name__)
 class CreateForm(forms.SelfHandlingForm):
     name = forms.CharField(max_length=255, label=_("Router Name"),
                            required=False)
-    admin_state_up = forms.BooleanField(label=_("Enable Admin State"),
-                                        initial=True,
-                                        required=False)
+    admin_state_up = forms.BooleanField(
+        label=_("Enable Admin State"),
+        initial=True,
+        required=False,
+        help_text=_("If checked, the router will be enabled."))
     external_network = forms.ThemableChoiceField(label=_("External Network"),
                                                  required=False)
     enable_snat = forms.BooleanField(label=_("Enable SNAT"),
@@ -145,7 +147,10 @@ class CreateForm(forms.SelfHandlingForm):
             if exc.status_code == 409:
                 msg = _('Quota exceeded for resource router.')
             else:
-                msg = _('Failed to create router "%s".') % data['name']
+                if data["name"]:
+                    msg = _('Failed to create router "%s".') % data['name']
+                else:
+                    msg = _('Failed to create router.')
             redirect = reverse(self.failure_url)
             exceptions.handle(request, msg, redirect=redirect)
             return False
@@ -153,8 +158,10 @@ class CreateForm(forms.SelfHandlingForm):
 
 class UpdateForm(forms.SelfHandlingForm):
     name = forms.CharField(label=_("Name"), required=False)
-    admin_state = forms.BooleanField(label=_("Enable Admin State"),
-                                     required=False)
+    admin_state = forms.BooleanField(
+        label=_("Enable Admin State"),
+        required=False,
+        help_text=_("If checked, the router will be enabled."))
     mode = forms.ThemableChoiceField(label=_("Router Type"))
     ha = forms.BooleanField(label=_("High Availability Mode"), required=False)
 
@@ -203,5 +210,6 @@ class UpdateForm(forms.SelfHandlingForm):
         except Exception as exc:
             LOG.info('Failed to update router %(id)s: %(exc)s',
                      {'id': self.initial['router_id'], 'exc': exc})
-            msg = _('Failed to update router %s') % data['name']
+            name_or_id = data['name'] or self.initial['router_id']
+            msg = _('Failed to update router %s') % name_or_id
             exceptions.handle(request, msg, redirect=self.redirect_url)
