@@ -19,8 +19,8 @@
 """
 Views for managing instances.
 """
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 from neutronclient.common import exceptions as neutron_exc
 
@@ -168,9 +168,12 @@ class CreateView(forms.ModalFormView):
     submit_label = _("Create Security Group")
     submit_url = reverse_lazy(
         "horizon:project:security_groups:create")
-    success_url = reverse_lazy('horizon:project:security_groups:index')
     page_title = _("Create Security Group")
 
+    def get_success_url_from_handled(self, handled):
+        return reverse('horizon:project:security_groups:detail',
+                       args=[handled.id])
+
 
 class IndexView(tables.DataTableView):
     table_class = project_tables.SecurityGroupsTable
