@@ -205,8 +205,6 @@
         // REQUIRED for JS logic
         hide_create_volume: false,
         vol_create: false,
-        // May be null
-        vol_device_name: 'vda',
         vol_delete_on_instance_delete: false,
         vol_size: 1
       };
@@ -249,6 +247,10 @@
         model.allowedBootSources.length = 0;
 
         var launchInstanceDefaults = settings.getSetting('LAUNCH_INSTANCE_DEFAULTS');
+        settings.getSetting('DEFAULT_BOOT_SOURCE').then(
+          function (response) {
+            model.defaultBootSource = response;
+          });
 
         promise = $q.all([
           novaAPI.getAvailabilityZones().then(onGetAvailabilityZones)
@@ -565,7 +567,12 @@
 
       if (enabledImage || enabledSnapshot) {
         var filter = {status: 'active', sort_key: 'name', sort_dir: 'asc'};
-        glanceAPI.getImages(filter).then(
+        var filterCommunity = angular.merge({}, filter, {visibility: 'community'});
+        var imagePromises = [
+          glanceAPI.getImages(filter),
+          glanceAPI.getImages(filterCommunity)
+        ];
+        $q.all(imagePromises).then(
           function(data) {
             onGetImageSources(data, enabledImage, enabledSnapshot);
           }
@@ -676,12 +683,21 @@
       model.imageSnapshots.length = 0;
       model.images.length = 0;
 
-      angular.forEach(data.data.items, function(image) {
-        if (isValidSnapshot(image) && enabledSnapshot) {
-          model.imageSnapshots.push(image);
-        } else if (isValidImage(image) && enabledImage) {
-          model.images.push(image);
-        }
+      var imageIdsProcessed = [];
+
+      angular.forEach(data, function(data) {
+        angular.forEach(data.data.items, function(image) {
+          if (imageIdsProcessed.includes(image.id)) {
+            return;
+          }
+          imageIdsProcessed.push(image.id);
+          if (isValidSnapshot(image) && enabledSnapshot) {
+            model.imageSnapshots.push(image);
+          } else if (isValidImage(image) && enabledImage) {
+            image.name_or_id = image.name || image.id;
+            model.images.push(image);
+          }
+        });
       });
 
       if (enabledImage) {
@@ -728,10 +744,13 @@
 
     function addAllowedBootSource(rawTypes, type, label) {
       if (rawTypes) {
+        var selected = model.defaultBootSource === type;
         model.allowedBootSources.push({
           type: type,
-          label: label
+          label: label,
+          selected: selected
         });
+
         model.allowedBootSources.sort(function(a, b) {
           return a.type > b.type;
         });
@@ -750,10 +769,10 @@
           setFinalSpecBootImageToVolume(finalSpec);
           break;
         case bootSourceTypes.VOLUME:
-          setFinalSpecBootFromVolumeDevice(finalSpec, 'vol');
+          setFinalSpecBootFromVolumeDevice(finalSpec, 'volume');
           break;
         case bootSourceTypes.VOLUME_SNAPSHOT:
-          setFinalSpecBootFromVolumeDevice(finalSpec, 'snap');
+          setFinalSpecBootFromVolumeDevice(finalSpec, 'snapshot');
           break;
         default:
           $log.error("Unknown source type: " + finalSpec.source_type);
@@ -765,7 +784,6 @@
       // at launch time.
       delete finalSpec.source_type;
       delete finalSpec.vol_create;
-      delete finalSpec.vol_device_name;
       delete finalSpec.vol_delete_on_instance_delete;
       delete finalSpec.vol_size;
     }
@@ -789,14 +807,16 @@
     }
 
     function setFinalSpecBootFromVolumeDevice(finalSpec, sourceType) {
-      finalSpec.block_device_mapping = {};
-      finalSpec.block_device_mapping[finalSpec.vol_device_name] = [
-        finalSpec.source_id,
-        ':',
-        sourceType,
-        '::',
-        finalSpec.vol_delete_on_instance_delete
-      ].join('');
+      finalSpec.block_device_mapping_v2 = [];
+      finalSpec.block_device_mapping_v2.push(
+        {
+          'source_type': sourceType,
+          'destination_type': bootSourceTypes.VOLUME,
+          'delete_on_termination': finalSpec.vol_delete_on_instance_delete,
+          'uuid': finalSpec.source_id,
+          'boot_index': '0'
+        }
+      );
 
       // Source ID must be empty for API
       finalSpec.source_id = '';
