@@ -530,8 +530,8 @@ ANGULAR_FEATURES = {
 # See: https://wiki.openstack.org/wiki/Horizon/RESTAPI
 REST_API_REQUIRED_SETTINGS = [
     'CREATE_IMAGE_DEFAULTS',
-    'DEFAULT_BOOT_SOURCE'
-    'ENFORCE_PASSWORD_CHECK'
+    'DEFAULT_BOOT_SOURCE',
+    'ENFORCE_PASSWORD_CHECK',
     'LAUNCH_INSTANCE_DEFAULTS',
     'OPENSTACK_HYPERVISOR_FEATURES',
     'OPENSTACK_IMAGE_FORMATS',
