@@ -12,13 +12,13 @@
 #    under the License.
 
 
-from django.conf import settings
+from horizon.utils import settings as utils_settings
 
 
 def check(actions, request, target=None):
     """Wrapper of the configurable policy method."""
 
-    policy_check = getattr(settings, "POLICY_CHECK_FUNCTION", None)
+    policy_check = utils_settings.import_setting("POLICY_CHECK_FUNCTION")
 
     if policy_check:
         return policy_check(actions, request, target)
@@ -39,6 +39,7 @@ class PolicyTargetMixin(object):
     """
 
     policy_target_attrs = (("project_id", "tenant_id"),
+                           ("tenant_id", "tenant_id"),
                            ("user_id", "user_id"),
                            ("domain_id", "domain_id"),
                            ("target.project.domain_id", "domain_id"),
