@@ -20,6 +20,7 @@ import glob
 import logging
 import os
 import sys
+import warnings
 
 from django.utils.translation import ugettext_lazy as _
 
@@ -36,10 +37,12 @@ monkeypatch_escape()
 
 # Load default values
 # pylint: disable=wrong-import-position
-from openstack_dashboard.defaults import *  # noqa: F403,H303
+from openstack_dashboard.defaults import *  # noqa: E402,F403,H303
 
 _LOG = logging.getLogger(__name__)
 
+warnings.filterwarnings("default", category=DeprecationWarning)
+
 ROOT_PATH = os.path.dirname(os.path.abspath(__file__))
 
 if ROOT_PATH not in sys.path:
