@@ -29,9 +29,7 @@ def is_multi_region_configured(request):
 
 def is_multidomain_supported():
     return (keystone.VERSIONS.active >= 3 and
-            getattr(settings,
-                    'OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT',
-                    False))
+            settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT)
 
 
 @register.simple_tag(takes_context=True)
@@ -80,7 +78,7 @@ def show_domain_list(context):
 @register.inclusion_tag('context_selection/_project_list.html',
                         takes_context=True)
 def show_project_list(context):
-    max_proj = getattr(settings, 'DROPDOWN_MAX_ITEMS', 30)
+    max_proj = settings.DROPDOWN_MAX_ITEMS
     if 'request' not in context:
         return {}
     request = context['request']
@@ -110,10 +108,7 @@ def show_region_list(context):
 @register.inclusion_tag('context_selection/_anti_clickjack.html',
                         takes_context=True)
 def iframe_embed_settings(context):
-    disallow_iframe_embed = getattr(settings,
-                                    'DISALLOW_IFRAME_EMBED',
-                                    True)
-    context = {'disallow_iframe_embed': disallow_iframe_embed}
+    context = {'disallow_iframe_embed': settings.DISALLOW_IFRAME_EMBED}
     return context
 
 
