@@ -109,7 +109,8 @@ class TestMetadataDefinitions(helpers.AdminTestCase):
         * 11) Check that new Namespace was successfully deleted.
         * 12) Check that new Namespace is not present in the table.
         """
-        namespaces_page = self.home_pg.go_to_system_metadatadefinitionspage()
+        namespaces_page = \
+            self.home_pg.go_to_admin_system_metadatadefinitionspage()
 
         template_json_container = namespaces_page.json_load_template(
             namespace_template_name=self.NAMESPACE_TEMPLATE_PATH)
