@@ -12,7 +12,6 @@
 
 import random
 
-from openstack_dashboard.test.integration_tests import decorators
 from openstack_dashboard.test.integration_tests import helpers
 from openstack_dashboard.test.integration_tests.regions import messages
 
@@ -28,10 +27,18 @@ class TestSecuritygroup(helpers.TestCase):
 
     def _create_securitygroup(self):
         page = self.securitygroup_page
-        page.create_securitygroup(self.SEC_GROUP_NAME)
-        self.assertTrue(page.find_message_and_dismiss(messages.SUCCESS))
-        self.assertFalse(page.find_message_and_dismiss(messages.ERROR))
-        self.assertTrue(page.is_securitygroup_present(self.SEC_GROUP_NAME))
+        rule_page = page.create_securitygroup(self.SEC_GROUP_NAME)
+        if rule_page:
+            self.assertTrue(
+                rule_page.find_message_and_dismiss(messages.SUCCESS))
+            self.assertFalse(
+                rule_page.find_message_and_dismiss(messages.ERROR))
+            page = self.securitygroup_page
+            self.assertTrue(page.is_securitygroup_present(self.SEC_GROUP_NAME))
+        else:
+            self.assertTrue(page.find_message_and_dismiss(messages.SUCCESS))
+            self.assertFalse(page.find_message_and_dismiss(messages.ERROR))
+            self.assertTrue(page.is_securitygroup_present(self.SEC_GROUP_NAME))
 
     def _delete_securitygroup(self):
         page = self.securitygroup_page
@@ -63,7 +70,6 @@ class TestSecuritygroup(helpers.TestCase):
         self.assertFalse(page.find_message_and_dismiss(messages.ERROR))
         self.assertFalse(page.is_port_present(self.RULE_PORT))
 
-    @decorators.skip_because(bugs=['1792028'])
     def test_securitygroup_create_delete(self):
         """tests the security group creation and deletion functionalities:
 
@@ -76,7 +82,6 @@ class TestSecuritygroup(helpers.TestCase):
         self._create_securitygroup()
         self._delete_securitygroup()
 
-    @decorators.skip_because(bugs=['1792028'])
     def test_managerules_create_delete_by_row(self):
         """tests the manage rules creation and deletion functionalities:
 
@@ -95,7 +100,6 @@ class TestSecuritygroup(helpers.TestCase):
         self._delete_rule_by_row_action()
         self._delete_securitygroup()
 
-    @decorators.skip_because(bugs=['1792028'])
     def test_managerules_create_delete_by_table(self):
         """tests the manage rules creation and deletion functionalities:
 
